@@ -1,7 +1,7 @@
 ;;; -*- Mode: LISP; Syntax: COMMON-LISP; Package: CL-GD; Base: 10 -*-
-;;; $Header: /usr/local/cvsrep/gd/cl-gd-test.lisp,v 1.20 2004/11/26 16:10:38 edi Exp $
+;;; $Header: /usr/local/cvsrep/gd/cl-gd-test.lisp,v 1.24 2005/09/26 12:50:11 edi Exp $
 
-;;; Copyright (c) 2003-2004, Dr. Edmund Weitz.  All rights reserved.
+;;; Copyright (c) 2003-2005, Dr. Edmund Weitz.  All rights reserved.
 
 ;;; Redistribution and use in source and binary forms, with or without
 ;;; modification, are permitted provided that the following conditions
@@ -39,8 +39,8 @@
 (defparameter *test-directory*
   (merge-pathnames (make-pathname :directory '(:relative "test"))
                    (make-pathname :name nil
-                                  :type :unspecific
-                                  :version :unspecific
+                                  :type nil
+                                  :version :newest
                                   :defaults cl-gd.system:*cl-gd-directory*))
   
   "Where test files are put.")
@@ -251,7 +251,8 @@
                                      orange orange orange))
           (write-image-to-file file
                                :compression-level 8
-                               :if-exists :supersede))))))
+                               :if-exists :supersede))))
+    (compare-files file)))
 
 (defun test-013 ()
   (let ((file (test-file-location "brushed-arc" "png")))
