@@ -1,7 +1,7 @@
 ;;; -*- Mode: LISP; Syntax: COMMON-LISP; Package: CL-GD; Base: 10 -*-
-;;; $Header: /usr/local/cvsrep/gd/colors-aux.lisp,v 1.7 2004/11/26 16:10:38 edi Exp $
+;;; $Header: /usr/local/cvsrep/gd/colors-aux.lisp,v 1.10 2005/03/09 14:17:56 edi Exp $
 
-;;; Copyright (c) 2003-2004, Dr. Edmund Weitz.  All rights reserved.
+;;; Copyright (c) 2003-2005, Dr. Edmund Weitz.  All rights reserved.
 
 ;;; Redistribution and use in source and binary forms, with or without
 ;;; modification, are permitted provided that the following conditions
@@ -154,7 +154,7 @@ argument for GD, modifying internal slots of IMAGE if needed."
                         image)
       +anti-aliased+)
     ((or vector list)
-      (setf (current-style image) (cdr color))
+      (setf (current-style image) color)
       +styled+)
     (integer
       color)))
