@@ -1,7 +1,7 @@
 ;;; -*- Mode: LISP; Syntax: COMMON-LISP; Package: CL-GD; Base: 10 -*-
-;;; $Header: /usr/local/cvsrep/gd/gd-uffi.lisp,v 1.24 2004/11/26 16:10:38 edi Exp $
+;;; $Header: /usr/local/cvsrep/gd/gd-uffi.lisp,v 1.28 2005/05/17 16:59:22 edi Exp $
 
-;;; Copyright (c) 2003-2004, Dr. Edmund Weitz.  All rights reserved.
+;;; Copyright (c) 2003-2005, Dr. Edmund Weitz.  All rights reserved.
 
 ;;; Redistribution and use in source and binary forms, with or without
 ;;; modification, are permitted provided that the following conditions
@@ -64,7 +64,7 @@
   (aal-x1 :int)
   (aal-y1 :int)
   (aal-x2 :int)
-  (aal-y1 :int)
+  (aal-y2 :int)
   (aal-bx-ax :int)
   (aal-by-ay :int)
   (aal-lab-2 :int)
@@ -180,6 +180,7 @@
   :returning gd-image-ptr
   :module "gd")
 
+#-:cl-gd-no-gif
 (def-function ("gdImageCreateFromGifFile" gd-image-create-from-gif-file)
     ((filename :cstring)
      (err (* :int)))
@@ -225,6 +226,7 @@
   :returning :pointer-void
   :module "gd")
 
+#-:cl-gd-no-gif
 (def-function ("gdImageGifPtr" gd-image-gif-ptr)
     ((im gd-image-ptr)
      (size (* :int)))
